package de.intevation.flys.artifacts.states;

import java.util.List;
import java.util.Map;

import org.apache.log4j.Logger;

import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.artifacts.context.FLYSContext;
import de.intevation.flys.artifacts.model.WMSLayerFacet;
import de.intevation.flys.artifacts.resources.Resources;
import de.intevation.flys.artifacts.states.DefaultState.ComputeType;


public class RiverAxisState extends OutputState {

    public static final String I18N_DESCRIPTION = "floodmap.riveraxis";

    public static final String WMS_LAYER_NAME = "riveraxis";


    private static final Logger logger = Logger.getLogger(RiverAxisState.class);


    @Override
    public Object computeInit(
        FLYSArtifact artifact,
        String       hash,
        Object       context,
        CallMeta     meta,
        List<Facet>  facets
    ) {
        logger.debug("RiverAxisState.computeInit()");

        FLYSContext flysContext = null;

        if (context instanceof FLYSContext) {
            flysContext = (FLYSContext) context;
        }
        else {
            flysContext = (FLYSContext) ((CallContext) context).globalContext();
        }

        Map<String, String> wms = (Map<String, String>)
            flysContext.get(FLYSContext.RIVER_WMS);

        String river = artifact.getDataAsString("river");

        if(river == null || river.length() == 0) {
            logger.warn("No river found in the current parameterization.");
            return null;
        }

        String url = wms.get(river);

        // TODO Add config for background layer
        WMSLayerFacet facet = new WMSLayerFacet(
            0,
            FLOODMAP_RIVERAXIS,
            Resources.getMsg(meta, I18N_DESCRIPTION, I18N_DESCRIPTION),
            ComputeType.INIT,
            getID(), hash,
            url);

        facet.addLayer(WMS_LAYER_NAME);

        // TODO determine extent based on the given geometry
        facet.setExtent("6.5 49.1 7.0 49.7");

        facets.add(facet);

        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
